==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/ZadluzenieWyrownanie.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import pl.topteam.dps.enums.StatusWyrownania;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class ZadluzenieWyrownanie extends GenericDPSObject {
    /**
     * ZADLUZENIE_WYROWNANIE.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * ZADLUZENIE_WYROWNANIE.FAKTURA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long fakturaId;

    /**
     * ZADLUZENIE_WYROWNANIE.NOTA_POZYCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long notaPozycjaId;

    /**
     * ZADLUZENIE_WYROWNANIE.ODPIS_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long odpisId;

    /**
     * ZADLUZENIE_WYROWNANIE.ZADLUZENIE_POZYCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long zadluzeniePozycjaId;

    /**
     * ZADLUZENIE_WYROWNANIE.ZWROT_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long zwrotId;

    /**
     * ZADLUZENIE_WYROWNANIE.KWOTA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwota;

    /**
     * ZADLUZENIE_WYROWNANIE.STATUS
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private StatusWyrownania status;

    /**
     * ZADLUZENIE_WYROWNANIE.KWOTA_ODPISU
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwotaOdpisu;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZADLUZENIE_WYROWNANIE.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ZADLUZENIE_WYROWNANIE.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ZADLUZENIE_WYROWNANIE.FAKTURA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getFakturaId() {
        return fakturaId;
    }

    /**
     * ZADLUZENIE_WYROWNANIE.FAKTURA_ID
     *
     * @param fakturaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setFakturaId(Long fakturaId) {
        this.fakturaId = fakturaId;
    }

    /**
     * @return ZADLUZENIE_WYROWNANIE.NOTA_POZYCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getNotaPozycjaId() {
        return notaPozycjaId;
    }

    /**
     * ZADLUZENIE_WYROWNANIE.NOTA_POZYCJA_ID
     *
     * @param notaPozycjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNotaPozycjaId(Long notaPozycjaId) {
        this.notaPozycjaId = notaPozycjaId;
    }

    /**
     * @return ZADLUZENIE_WYROWNANIE.ODPIS_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOdpisId() {
        return odpisId;
    }

    /**
     * ZADLUZENIE_WYROWNANIE.ODPIS_ID
     *
     * @param odpisId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOdpisId(Long odpisId) {
        this.odpisId = odpisId;
    }

    /**
     * @return ZADLUZENIE_WYROWNANIE.ZADLUZENIE_POZYCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getZadluzeniePozycjaId() {
        return zadluzeniePozycjaId;
    }

    /**
     * ZADLUZENIE_WYROWNANIE.ZADLUZENIE_POZYCJA_ID
     *
     * @param zadluzeniePozycjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZadluzeniePozycjaId(Long zadluzeniePozycjaId) {
        this.zadluzeniePozycjaId = zadluzeniePozycjaId;
    }

    /**
     * @return ZADLUZENIE_WYROWNANIE.ZWROT_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getZwrotId() {
        return zwrotId;
    }

    /**
     * ZADLUZENIE_WYROWNANIE.ZWROT_ID
     *
     * @param zwrotId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZwrotId(Long zwrotId) {
        this.zwrotId = zwrotId;
    }

    /**
     * @return ZADLUZENIE_WYROWNANIE.KWOTA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * ZADLUZENIE_WYROWNANIE.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return ZADLUZENIE_WYROWNANIE.STATUS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public StatusWyrownania getStatus() {
        return status;
    }

    /**
     * ZADLUZENIE_WYROWNANIE.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setStatus(StatusWyrownania status) {
        this.status = status;
    }

    /**
     * @return ZADLUZENIE_WYROWNANIE.KWOTA_ODPISU
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwotaOdpisu() {
        return kwotaOdpisu;
    }

    /**
     * ZADLUZENIE_WYROWNANIE.KWOTA_ODPISU
     *
     * @param kwotaOdpisu
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwotaOdpisu(BigDecimal kwotaOdpisu) {
        this.kwotaOdpisu = kwotaOdpisu;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZadluzenieWyrownanie other = (ZadluzenieWyrownanie) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getFakturaId() == null ? other.getFakturaId() == null : this.getFakturaId().equals(other.getFakturaId()))
            && (this.getNotaPozycjaId() == null ? other.getNotaPozycjaId() == null : this.getNotaPozycjaId().equals(other.getNotaPozycjaId()))
            && (this.getOdpisId() == null ? other.getOdpisId() == null : this.getOdpisId().equals(other.getOdpisId()))
            && (this.getZadluzeniePozycjaId() == null ? other.getZadluzeniePozycjaId() == null : this.getZadluzeniePozycjaId().equals(other.getZadluzeniePozycjaId()))
            && (this.getZwrotId() == null ? other.getZwrotId() == null : this.getZwrotId().equals(other.getZwrotId()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()))
            && (this.getKwotaOdpisu() == null ? other.getKwotaOdpisu() == null : this.getKwotaOdpisu().equals(other.getKwotaOdpisu()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getFakturaId() == null) ? 0 : getFakturaId().hashCode());
        result = prime * result + ((getNotaPozycjaId() == null) ? 0 : getNotaPozycjaId().hashCode());
        result = prime * result + ((getOdpisId() == null) ? 0 : getOdpisId().hashCode());
        result = prime * result + ((getZadluzeniePozycjaId() == null) ? 0 : getZadluzeniePozycjaId().hashCode());
        result = prime * result + ((getZwrotId() == null) ? 0 : getZwrotId().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        result = prime * result + ((getKwotaOdpisu() == null) ? 0 : getKwotaOdpisu().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", fakturaId=").append(fakturaId);
        sb.append(", notaPozycjaId=").append(notaPozycjaId);
        sb.append(", odpisId=").append(odpisId);
        sb.append(", zadluzeniePozycjaId=").append(zadluzeniePozycjaId);
        sb.append(", zwrotId=").append(zwrotId);
        sb.append(", kwota=").append(kwota);
        sb.append(", status=").append(status);
        sb.append(", kwotaOdpisu=").append(kwotaOdpisu);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/ZadluzenieWyrownanie.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import pl.topteam.dps.enums.StatusWyrownania;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class ZadluzenieWyrownanie extends GenericDPSObject {
    /**
     * ZADLUZENIE_WYROWNANIE.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * ZADLUZENIE_WYROWNANIE.FAKTURA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long fakturaId;

    /**
     * ZADLUZENIE_WYROWNANIE.NOTA_POZYCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long notaPozycjaId;

    /**
     * ZADLUZENIE_WYROWNANIE.ODPIS_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long odpisId;

    /**
     * ZADLUZENIE_WYROWNANIE.ZADLUZENIE_POZYCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long zadluzeniePozycjaId;

    /**
     * ZADLUZENIE_WYROWNANIE.ZWROT_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long zwrotId;

    /**
     * ZADLUZENIE_WYROWNANIE.KWOTA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwota;

    /**
     * ZADLUZENIE_WYROWNANIE.STATUS
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private StatusWyrownania status;

    /**
     * ZADLUZENIE_WYROWNANIE.KWOTA_ODPISU
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwotaOdpisu;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZADLUZENIE_WYROWNANIE.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ZADLUZENIE_WYROWNANIE.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ZADLUZENIE_WYROWNANIE.FAKTURA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getFakturaId() {
        return fakturaId;
    }

    /**
     * ZADLUZENIE_WYROWNANIE.FAKTURA_ID
     *
     * @param fakturaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setFakturaId(Long fakturaId) {
        this.fakturaId = fakturaId;
    }

    /**
     * @return ZADLUZENIE_WYROWNANIE.NOTA_POZYCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getNotaPozycjaId() {
        return notaPozycjaId;
    }

    /**
     * ZADLUZENIE_WYROWNANIE.NOTA_POZYCJA_ID
     *
     * @param notaPozycjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNotaPozycjaId(Long notaPozycjaId) {
        this.notaPozycjaId = notaPozycjaId;
    }

    /**
     * @return ZADLUZENIE_WYROWNANIE.ODPIS_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOdpisId() {
        return odpisId;
    }

    /**
     * ZADLUZENIE_WYROWNANIE.ODPIS_ID
     *
     * @param odpisId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOdpisId(Long odpisId) {
        this.odpisId = odpisId;
    }

    /**
     * @return ZADLUZENIE_WYROWNANIE.ZADLUZENIE_POZYCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getZadluzeniePozycjaId() {
        return zadluzeniePozycjaId;
    }

    /**
     * ZADLUZENIE_WYROWNANIE.ZADLUZENIE_POZYCJA_ID
     *
     * @param zadluzeniePozycjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZadluzeniePozycjaId(Long zadluzeniePozycjaId) {
        this.zadluzeniePozycjaId = zadluzeniePozycjaId;
    }

    /**
     * @return ZADLUZENIE_WYROWNANIE.ZWROT_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getZwrotId() {
        return zwrotId;
    }

    /**
     * ZADLUZENIE_WYROWNANIE.ZWROT_ID
     *
     * @param zwrotId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZwrotId(Long zwrotId) {
        this.zwrotId = zwrotId;
    }

    /**
     * @return ZADLUZENIE_WYROWNANIE.KWOTA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * ZADLUZENIE_WYROWNANIE.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return ZADLUZENIE_WYROWNANIE.STATUS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public StatusWyrownania getStatus() {
        return status;
    }

    /**
     * ZADLUZENIE_WYROWNANIE.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setStatus(StatusWyrownania status) {
        this.status = status;
    }

    /**
     * @return ZADLUZENIE_WYROWNANIE.KWOTA_ODPISU
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwotaOdpisu() {
        return kwotaOdpisu;
    }

    /**
     * ZADLUZENIE_WYROWNANIE.KWOTA_ODPISU
     *
     * @param kwotaOdpisu
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwotaOdpisu(BigDecimal kwotaOdpisu) {
        this.kwotaOdpisu = kwotaOdpisu;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZadluzenieWyrownanie other = (ZadluzenieWyrownanie) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getFakturaId() == null ? other.getFakturaId() == null : this.getFakturaId().equals(other.getFakturaId()))
            && (this.getNotaPozycjaId() == null ? other.getNotaPozycjaId() == null : this.getNotaPozycjaId().equals(other.getNotaPozycjaId()))
            && (this.getOdpisId() == null ? other.getOdpisId() == null : this.getOdpisId().equals(other.getOdpisId()))
            && (this.getZadluzeniePozycjaId() == null ? other.getZadluzeniePozycjaId() == null : this.getZadluzeniePozycjaId().equals(other.getZadluzeniePozycjaId()))
            && (this.getZwrotId() == null ? other.getZwrotId() == null : this.getZwrotId().equals(other.getZwrotId()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()))
            && (this.getKwotaOdpisu() == null ? other.getKwotaOdpisu() == null : this.getKwotaOdpisu().equals(other.getKwotaOdpisu()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getFakturaId() == null) ? 0 : getFakturaId().hashCode());
        result = prime * result + ((getNotaPozycjaId() == null) ? 0 : getNotaPozycjaId().hashCode());
        result = prime * result + ((getOdpisId() == null) ? 0 : getOdpisId().hashCode());
        result = prime * result + ((getZadluzeniePozycjaId() == null) ? 0 : getZadluzeniePozycjaId().hashCode());
        result = prime * result + ((getZwrotId() == null) ? 0 : getZwrotId().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        result = prime * result + ((getKwotaOdpisu() == null) ? 0 : getKwotaOdpisu().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", fakturaId=").append(fakturaId);
        sb.append(", notaPozycjaId=").append(notaPozycjaId);
        sb.append(", odpisId=").append(odpisId);
        sb.append(", zadluzeniePozycjaId=").append(zadluzeniePozycjaId);
        sb.append(", zwrotId=").append(zwrotId);
        sb.append(", kwota=").append(kwota);
        sb.append(", status=").append(status);
        sb.append(", kwotaOdpisu=").append(kwotaOdpisu);
        sb.append("]");
        return sb.toString();
    }
}
